# -*- coding: utf-8 -*-
from setuptools import setup

package_dir = \
{'': 'src'}

packages = \
['cwafctl']

package_data = \
{'': ['*']}

install_requires = \
['PyYAML>=5.4.1,<6.0.0',
 'certifi>=2020.12.5,<2021.0.0',
 'cffi>=1.14.5,<2.0.0',
 'chardet>=4.0.0,<5.0.0',
 'cryptography>=3.4.7,<4.0.0',
 'fire>=0.4.0,<0.5.0',
 'idna>=2.10,<3.0',
 'lxml==4.6.3',
 'pyOpenSSL>=20.0.1,<21.0.0',
 'pycparser>=2.20,<3.0',
 'requests>=2.25.1,<3.0.0',
 'six>=1.16.0,<2.0.0',
 'termcolor>=1.1.0,<2.0.0',
 'urllib3>=1.26.4,<2.0.0']

entry_points = \
{'console_scripts': ['cwafctl = cwafctl.cwafctl:start']}

setup_kwargs = {
    'name': 'cwafctl',
    'version': '0.4.0',
    'description': 'Radware Cloud WAF command-line tool',
    'long_description': '# cwafctl\n\n**cwafctl** is a command-line utility that interfaces with Radware Cloud WAF over REST API. It allows to manage Cloud WAF from the CLI.\n\n**cwafctl** works with yaml, it allows you to retrieve information in yaml format, that you can save to a file, modify and later on re-use to update the object. The yaml objects used by cwafctl are mapped directly to the JSON format supported by Cloud WAF for API calls.\n\n**cwafctl** requires **python 3.8** to run and was tested using windows 10.\n\n# How to install\nYou can use the python package installer "pip" to deploy cwafctl:\n\n    pip install cwafctl\n\nIn order to configure your user name and password, please use the following command initially:\n\n    cwafctl utils setUserNameAndPassword --username="username@domain.com" --password="password"\n\nwhere username and password are Radware Cloud WAF API credentials. It will store those credentials in the user home folder. <br><br>\n\nFor instructions on how to create an API user in Cloud WAF, please consult https://portals.radware.com/ProductDocumentation/Cloud_WAF_API_User_Guide/index.html#page/Cloud%20WAF%20API%20User%20Guide/Cloud%20WAF%20API%20Users%20Guide%20v6_AB.1.09.html\n\n\n# How to use\ncwafctl basically implements the commands below:\n * **get** :    Allows to retrieve a configuration\n * **create**:  Allows to deploy new configurations (ex.:new application,certificate,etc.)\n * **delete**:  Allows to delete an object\n * **set**:     Allows to modify an existing configuration\n * **utils**:   Misc utilities\n\n## Retrieving objects using the "get" command\nIn order to list applications currently onboarded on your cloud waf account and retrieve the information in yaml format:\n\n    cwafctl get applications\n\nThis an example of the CLI output:\n\n\n        applications:\n        - accountId: 607b9775-a04a-4efa-ba97-228909abc300\n          accountName: US Region PoCs\n          applicationId: 9d8213f6-580f-406c-9bda-618ef9b3896d\n          applicationName: Juice Shop\n          creationDate: 1617758940383\n          customDeployment: false\n          deploymentStatus: PROTECTING\n          frontend: alcon\n          mainDomain: juice-shop.herokuapp.com\n          region: North America (Ashburn)\n        - accountId: 607b9775-a04a-4efa-ba97-228909abc300\n          accountName: US Region PoCs\n          applicationId: db3718bc-de94-40c1-9adf-300a41069e44\n          applicationName: rs_hackazon\n          creationDate: 1598545097301\n          customDeployment: false\n          deploymentStatus: PROTECTING\n          frontend: alcon\n          mainDomain: rsamazon.ddns.net\n          region: North America (Ashburn)\n        ....\n        numberOfElements: 7\n        page: 0\n        totalElements: 7\n        totalPages: 1\n\nYou can dump the content directly to a yaml file by using the following syntax:<br>\n\n    cwafctl get applications > applications.yaml\n\n\nIn order to list certificates deployed in your account and dump it to a yaml file:\n\n    cwafctl get certificates > certificates.yaml\n\n\nIn order to get a specific application configuration and dump it to a yaml file:\n\n    cwafctl get application "HacmeBank" > hacmebankapp.yaml\n\n\nTo get the full list of available commands and objects that are retrievable:\n\n    cwafctl get --help\n\n\n To get help on a specific command, you can use the following syntax:\n\n    cwafctl get application --help\n\n CLI Output:\n\n    python cwafctl get application --help\n    INFO: Showing help with the command \'cwafctl get application -- --help\'.\n\n    NAME\n        cwafctl get application - Gets an application configuration by name in YAML\n\n    SYNOPSIS\n        cwafctl get application NAME\n\n    DESCRIPTION\n        Gets an application configuration by name in YAML\n\n    POSITIONAL ARGUMENTS\n        NAME\n\n    NOTES\n        You can also use flags syntax for POSITIONAL ARGUMENTS\n\n\n## Deploying objects using the "create" command\nIn order to deploy an application:\n\n    cwafctl create application < newapp.yaml  [see yaml folder for an example of a yaml file used to onboard an application]\n\nIn order to deploy a certificate:\n\n    cwafctl create certificate < certificate.yaml  [see the yaml folder for an example of how to onboard a certificate]\n\n## Deleting objects using the "delete" command\n\n**To delete a certificate:**\n\n    cwafctl delete certificate FINGERPRINT\n\nwhere **FINGERPRINT** is the SHA1 fingerprint of the public key. Certificate fingerprints can be extracted from Cloud WAF using the command: **cwafctl get certificates**"\n<br><br><br>\n**To delete an application:**\n\n    cwafctl delete application APPNAME\n\nwhere **APPNAME** is the application name.\n\n\n## Modifying existing configuration using the "get" and "set" command\n\nAny "get" command can be used to retrieve an object that can be stored and edited locally and later pushed using the "set" command.\n\n For example:\n\nThe following commands retrieve the "general information section of an application" and wil store it to a yaml file\n\n    cwafctl get application_generalinfo "HacmeBank" > generalInfo.yaml\n\nThe content of the yaml file is the following:\n\n    description: null\n    externalID: null\n    ownerEmail: null\n    ownerName: Christian Shink\n\nThe field "description" can be modified and edited  and the content becomes the folowing :\n\n    description: HacmeBank application\n    externalID: null\n    ownerEmail: null\n    ownerName: Christian Shink\n\nonce the field has been edited, the new General Info for the application "HacmeBank" can be set using the following command:\n\n    cwafctl set application_generalinfo "HacmeBank" < generalInfo.yaml\n\n\n## Deploying a new application using cwafctl\n\n**To deploy the certificate:**\n\n    cwafctl create certificate < ./"yaml files"/certificate.yaml\n\n**To deploy the application:**\n\n    cwafctl create application < ./"yaml files"/newapp.yaml\n\n\nThe "yaml files" folder contains yaml files that are usable to deploy a certificate specified in the certificate.yaml file along with a newapp.yaml file that specifies where to deploy the app. Those files can be edited and updated to match with your applications required deployment parameters.\n\n\n**newapp.yaml** file content:\n\n\n        applicationName: My application\n        mainDomain: www.test.com\n        protocol: BOTH\n        region: CANADA_1\n        originServers:\n        - address: 2.2.2.2\n          addressType: IP\n        - address: 3.3.3.3\n          addressType: IP\n        generalInfo:\n          ownerName: Christian Shink\n          ownerEmail: christian.shink@test.com\n          externalID: \'123445\'\n          description: test\n        fingerprint: 87FE361698CB3F47683245984DDAF08E334818D3\n\n\nPlease note that the sha1 "fingerprint" field above can be calculated before the deployment using the following command:\n\n    cwafctl utils get_certificate_fingerprint < ./"yaml files"/certificate.yaml\n\nPlease note that the available region codes can be obtained from cloud waf using the following commands:\n\n    cwafctl get available_regions\n\nCLI output:\n\n    - CANADA_1\n    - US_EAST_1\n    - US_CENTRAL_1\n\n\nPlease note that the "certificate.yaml" file can either be created manually using the same format as in ./"yaml files"/certificate.yaml or be generated using the following command:\n\n    cwafctl utils generate_yaml_cert_file certificate.pem key.pem certchain.pem test > certificate.yaml\n\n* where certificate.pem is the file containing the public key<br>\n* where key.pem is the file containing the private key<br>\n* where certchain.pem is the file containing the certificate chain<br>\n* where test is the passphrase that was used to encrypt the certificate<br>\n\n\n## Retrieving security events from Radware Cloud WAF\n<br>\nYou can retrieve waf events from Cloud WAF by using the following command:\n\n    cwafctl get events_waf\n\nIt will retrieve the top 10000 events ordered by date. You can in addition scope the search to a specific source IP or protected application by using the --sourceIP and --applicationName parameters.\n<br><br><br><br>\nYou can retrieve ddos events from Radware Cloud WAF using the following command:\n\n    cwafctl get events_ddos\n\nIt will retrieve the top 10000 events ordered by date. You can in addition scope the search to a specific source IP or destination IP or application by using the flags --sourceIP, --destinationIP and --applicationName.\n<br><br><br><br>\n\nFor customers using the Radware BOT manager integrated in Cloud WAF. You can retrieve the current list of bad bots using the following command:\n\n    cwafctl get bad_bots "appName"\n\nwhere "appName" is the name of the application protected by Cloud WAF.\n<br><br><br><br>\n\nFor customers using the Radware BOT manager integrated in Cloud WAF. You can retrieve the list of legitimate bots using the following command:\n\n    cwafctl get legitimate_bots "appName"\n\nwhere "appName" is the name of the application protected by Cloud WAF.\n<br><br><br><br>\n\nFor customers using the Radware BOT manager integrated in Cloud WAF. You can retrieve the list of search engines using the following command:\n\n    cwafctl get search_engine_bots "appName"\n\nwhere "appName" is the name of the application protected by Cloud WAF.\n<br><br><br><br>\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n',
    'author': 'Christian Shink',
    'author_email': 'christian.shink@radware.com',
    'maintainer': None,
    'maintainer_email': None,
    'url': 'https://github.com/Radware/CloudWAF-command-line-tool',
    'package_dir': package_dir,
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'entry_points': entry_points,
    'python_requires': '>=3.8,<4.0',
}


setup(**setup_kwargs)
